// SPDX-License-Identifier: GPL-3.0-only

use chacha20poly1305::aead;
use std::io;

#[derive(Debug)]
pub enum FcryError {
    Io(io::Error),
    Crypto(aead::Error),
    Rng(rand::Error),
}

impl From<io::Error> for FcryError {
    fn from(e: io::Error) -> Self {
        FcryError::Io(e)
    }
}

impl From<aead::Error> for FcryError {
    fn from(e: aead::Error) -> Self {
        FcryError::Crypto(e)
    }
}

impl From<rand::Error> for FcryError {
    fn from(e: rand::Error) -> Self {
        FcryError::Rng(e)
    }
}
