// SPDX-License-Identifier: GPL-3.0-only

mod crypto;
mod error;
mod reader;
mod utils;

use crypto::*;
use error::FcryError;

use clap::Parser;

/// fcry - [f]ile[cry]pt: A file en-/decryption tool for easy use
#[derive(Parser, Debug)]
#[clap(author, version, about)]
struct Cli {
    /// decrypt instead of encrypt (encryption is the default)
    #[clap(short, long)]
    decrypt: bool,

    /// The input file to en-/decrypt
    #[clap(short, long)]
    input_file: Option<String>,

    /// The output file.
    /// If not specified, en-/decrypted bytes will be sent to stdout
    #[clap(short, long)]
    output_file: Option<String>,

    /// The raw bytes of the crypto key.
    /// Has to be exactly 32 bytes
    /// *** DANGEROUS, use for testing purposes only! ***
    #[clap(short, long)]
    raw_key: String,
}

fn run(cli: Cli) -> Result<(), FcryError> {
    let input_file = cli.input_file;
    let output_file = cli.output_file;

    let mut key = [0u8; 32];
    dbg!(&cli.raw_key);
    key.clone_from_slice(cli.raw_key.as_bytes());

    if cli.decrypt {
        decrypt(input_file, output_file, key)?
    } else {
        encrypt(input_file, output_file, key)?
    }

    Ok(())
}

fn main() {
    let cli = Cli::parse();
    if let Err(e) = run(cli) {
        println!("Error: {:?}", e);
    }
}
